==> gameap-3.1-shared.zip: upload/resources/lang/en/users.php <==
<?php

return [
    'title_list' => 'Users List',
    'title_create' => 'Create User',
    'title_edit' => 'Edit User',

    'title_server_permissions_edit' => 'Edit Server Permission',
    
    'users' => 'Users',
    'user' => 'User',
    'login' => 'Login',
    'name' => 'Name',
    'roles' => 'Roles',
    
    'create' => 'Create User',
    
    'servers' => 'Servers',
    'servers_privileges_placeholder' => 'Start typing the server name',

    'permission_names' => [
        'game-server-common'        => 'Common Game Server Ability',
        'game-server-start'         => 'Start Game Server',
        'game-server-stop'          => 'Stop Game Server',
        'game-server-restart'       => 'Restart Game Server',
        'game-server-pause'         => 'Pause Game Server',
        'game-server-update'        => 'Update Game Server',
        'game-server-files'         => 'Access to filemanager',
        'game-server-tasks'         => 'Access to task scheduler',
        'game-server-settings'      => 'Access to settings',

        // Console
        'game-server-console-view'  => 'Access to read server console',
        'game-server-console-send'  => 'Access to send console commands',

        // RCON
        'game-server-rcon-console'  => 'RCON console',
        'game-server-rcon-players'  => 'RCON players manage',
    ],

    'server_permission_edit' => 'Edit Server Permission',

    'create_success_msg' => 'User created successfully',
    'update_success_msg' => 'User updated successfully',
    'delete_success_msg' => 'User deleted successfully',
];

==> gameap-3.2-shared.zip: upload/resources/lang/en/users.php <==
<?php

return [
    'title_list' => 'Users List',
    'title_create' => 'Create User',
    'title_edit' => 'Edit User',

    'title_server_permissions_edit' => 'Edit Server Permission',
    
    'users' => 'Users',
    'user' => 'User',
    'login' => 'Login',
    'name' => 'Name',
    'roles' => 'Roles',
    
    'create' => 'Create User',
    
    'servers' => 'Servers',
    'servers_privileges_placeholder' => 'Start typing the server name',

    'permission_names' => [
        'game-server-common'        => 'Common Game Server Ability',
        'game-server-start'         => 'Start Game Server',
        'game-server-stop'          => 'Stop Game Server',
        'game-server-restart'       => 'Restart Game Server',
        'game-server-pause'         => 'Pause Game Server',
        'game-server-update'        => 'Update Game Server',
        'game-server-files'         => 'Access to filemanager',
        'game-server-tasks'         => 'Access to task scheduler',
        'game-server-settings'      => 'Access to settings',

        // Console
        'game-server-console-view'  => 'Access to read server console',
        'game-server-console-send'  => 'Access to send console commands',

        // RCON
        'game-server-rcon-console'  => 'RCON console',
        'game-server-rcon-players'  => 'RCON players manage',
    ],

    'update_password' => 'Update Password',

    'server_permission_edit' => 'Edit Server Permission',

    'delete_confirm_msg' => 'Are you sure you want to delete this user?',

    'create_success_msg' => 'User created successfully',
    'update_success_msg' => 'User updated successfully',
    'delete_success_msg' => 'User deleted successfully',

    'privileges_saved_success_msg' => 'Privileges saved successfully',

    'delete_self_error_msg' => 'You can not delete yourself',
];
